AplTokenType

Enum AplTokenType 

pub enum AplTokenType {
Show 64 variants Whitespace, Newline, Comment, StringLiteral, NumberLiteral, Identifier, LeftArrow, RightArrow, Diamond, Quad, QuoteQuad, Rho, Iota, Epsilon, UpArrow, DownArrow, Del, Delta, Alpha, Omega, Zilde, Plus, Minus, Times, Divide, Star, Log, Circle, Or, And, Not, Nor, Nand, Equal, NotEqual, LessThan, LessEqual, GreaterEqual, GreaterThan, UpStile, DownStile, Bar, Tilde, Question, Factorial, Slash, Backslash, SlashBar, BackslashBar, Dot, Jot, Diaeresis, Power, Rank, Tally, LeftParen, RightParen, LeftBracket, RightBracket, LeftBrace, RightBrace, Semicolon, Eof, Error,
}
Token types for the APL language.

Variants



Whitespace

Whitespace.



Newline

A newline.



Comment

A comment (⍝).



StringLiteral

A string literal.



NumberLiteral

A number literal.



Identifier

An identifier.



LeftArrow

Left arrow (←).



RightArrow

Right arrow (→).



Diamond

Diamond (⋄).



Quad

Quad (⎕).



QuoteQuad

Quote quad (⍞).



Rho

Rho (⍴).



Iota

Iota (⍳).



Epsilon

Epsilon (∊).



UpArrow

Up arrow (↑).



DownArrow

Down arrow (↓).



Del

Del (∇).



Delta

Delta (∆).



Alpha

Alpha (⍺).



Omega

Omega (⍵).



Zilde

Zilde (⍬).



Plus

Plus (+).



Minus

Minus (-).



Times

Times (×).



Divide

Divide (÷).



Star

Star (*).



Log

Log (⍟).



Circle

Circle (○).



Or

Or (∨).



And

And (∧).



Not

Not (∼).



Nor

Nor (⍱).



Nand

Nand (⍲).



Equal

Equal (=).



NotEqual

Not equal (≠).



LessThan

Less than (<).



LessEqual

Less equal (≤).



GreaterEqual

Greater equal (≥).



GreaterThan

Greater than (>).



UpStile

Up stile (⌈).



DownStile

Down stile (⌊).



Bar

Bar (|).



Tilde

Tilde (∼).



Question

Question (?).



Factorial

Factorial (!).



Slash

Slash (/).



Backslash

Backslash ().



SlashBar

Slash bar (⌿).



BackslashBar

Backslash bar (⍀).



Dot

Dot (.).



Jot

Jot (∘).



Diaeresis

Diaeresis (¨).



Power

Power (⍣).



Rank

Rank (⍤).



Tally

Tally (≢).



LeftParen

Left parenthesis (().



RightParen

Right parenthesis ()).



LeftBracket

Left bracket ([).



RightBracket

Right bracket (]).



LeftBrace

Left brace ({).



RightBrace

Right brace (}).



Semicolon

Semicolon (;).



Eof

End of stream.



Error

An error token.

Implementations

Source

impl AplTokenType

pub fn is_identifier(&self) -> bool

Returns true if this token is an identifier.

pub fn is_literal(&self) -> bool

Returns true if this token is a literal.